tdub.ml_apply
-------------

A module for applying trained models

.. currentmodule:: tdub.ml_apply

Class Summary
^^^^^^^^^^^^^

.. autosummary::

   BaseTrainSummary
   FoldedTrainSummary
   SingleTrainSummary

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   build_array

Reference
^^^^^^^^^

.. autoclass:: BaseTrainSummary
   :members:

.. autoclass:: FoldedTrainSummary
   :members:
   :show-inheritance:

.. autoclass:: SingleTrainSummary
   :members:
   :show-inheritance:

.. autofunction:: build_array
